rm(list = ls())
Data <- read.csv("Testdata.csv", header=TRUE, sep=";")
head(Data)

fullmodel <- "# dependent regression
Y ~ b11*M + c11*X

# mediator regression
M ~ a11*X

# effect decomposition
# y1 ~ x1
ind_x1_m1_y1 := a11*b11
ind_x1_y1 := ind_x1_m1_y1
tot_x1_y1 := ind_x1_y1 + c11"
set.seed(1)
sem <- lavaan::sem(fullmodel, data = Data, se = "bootstrap",  bootstrap = 500)
lavaan::parameterEstimates(sem, 
                   se = TRUE, zstat = TRUE, pvalue = TRUE, ci = TRUE, 
                   standardized = TRUE, 
                   fmi = FALSE, level = 0.95, boot.ci.type = "bca.simple")

#output
#lhs op           rhs        label              est    se     z   pvalue ci.lower ci.upper std.lv std.all std.nox
# 1            Y  ~             M          b11 0.507 0.217 2.341  0.019    0.088    0.979  0.507   0.343   0.343
# 2            Y  ~             X          c11 0.153 0.250 0.611  0.541   -0.408    0.597  0.153   0.098   0.111
# 3            M  ~             X          a11 0.524 0.133 3.945  0.000    0.283    0.830  0.524   0.496   0.564
# 4            Y ~~             Y              1.578 0.219 7.200  0.000    1.195    2.078  1.578   0.839   0.839
# 5            M ~~             M              0.650 0.146 4.453  0.000    0.411    1.014  0.650   0.754   0.754
# 6            X ~~             X              0.772 0.000    NA     NA    0.772    0.772  0.772   1.000   0.772
# 7 ind_x1_m1_y1 :=       a11*b11 ind_x1_m1_y1 0.266 0.142 1.873  0.061    0.043    0.603  0.266   0.170   0.194
# 8    ind_x1_y1 :=  ind_x1_m1_y1    ind_x1_y1 0.266 0.142 1.873  0.061    0.043    0.603  0.266   0.170   0.194
# 9    tot_x1_y1 := ind_x1_y1+c11    tot_x1_y1 0.419 0.210 1.992  0.046   -0.034    0.823  0.419   0.268   0.305

#JASP OUTPUT
#           est     se      z       p       lower     upper
#Y ~ X:     0.068		0.141		0.487		0.626		-0.288		0.415	  <-> R: est: 0.153; p: 0.541
#indirect:  0.202		0.088		2.294		0.022		0.019		0.451     <-> R: est: 0.266; p: 0.061
#total:     0.271		0.123		2.207		0.027		0.014		0.518     <-> R: est: 0.419; p:0.046

